StrippedPolicyRuleServerEvent

Type Alias StrippedPolicyRuleServerEvent 

pub type StrippedPolicyRuleServerEvent = StrippedStateEvent<PossiblyRedactedPolicyRuleServerEventContent>;
An m.policy.rule.server event from an invited room preview.

Aliased Type

pub struct StrippedPolicyRuleServerEvent {
    pub content: PossiblyRedactedPolicyRuleServerEventContent,
    pub sender: OwnedUserId,
    pub state_key: String,
}

Fields

content: PossiblyRedactedPolicyRuleServerEventContent

Data specific to the event type.

sender: OwnedUserId

The fully-qualified ID of the user who sent this event.

state_key: String

A unique key which defines the overwriting semantics for this piece of room state.

This must be a string type, and is often an empty string.

A state event is keyed by its (type, state_key) tuple. Sending another state event with the same tuple replaces the previous one.